@@ -76,9 +76,8 @@ public class CompressTrackFunction extends MarkAndDeleteFunction
 	{
 		int numToDelete = 0;
 		boolean[] deleteFlags = new boolean[_track.getNumPoints()];
-		for (int i=0; i<_algorithms.length; i++)
-		{
-			numToDelete += _algorithms[i].preview(deleteFlags);
+		for (CompressionAlgorithm algorithm : _algorithms) {
+			numToDelete += algorithm.preview(deleteFlags);
 		}
 		_summaryLabel.setValue(numToDelete);
 		_okButton.setEnabled(numToDelete > 0);
@@ -100,9 +99,9 @@ public class CompressTrackFunction extends MarkAndDeleteFunction
 		mainPanel.setLayout(new BoxLayout(mainPanel, BoxLayout.Y_AXIS));
 
 		// Add each of the algorithm components to the panel
-		for (int i=0; i<_algorithms.length; i++)
+		for (CompressionAlgorithm algorithm : _algorithms)
 		{
-			mainPanel.add(_algorithms[i].getGuiComponents());
+			mainPanel.add(algorithm.getGuiComponents());
 			mainPanel.add(Box.createRigidArea(new Dimension(0, 2)));
 		}
 		// Summary label below algorithms
@@ -164,7 +163,7 @@ public class CompressTrackFunction extends MarkAndDeleteFunction
 			if (deletePoint) numMarked++;
 		}
 		// Save settings
-		Config.setConfigString(Config.KEY_COMPRESSION_SETTINGS, createConfigString());
+		getConfig().setConfigString(Config.KEY_COMPRESSION_SETTINGS, createConfigString());
 
 		// Close dialog and inform listeners
 		UpdateMessageBroker.informSubscribers();
@@ -184,7 +183,8 @@ public class CompressTrackFunction extends MarkAndDeleteFunction
 	/**
 	 * @return String describing all config settings
 	 */
-	private String createConfigString() {
+	private String createConfigString()
+	{
 		StringBuilder builder = new StringBuilder();
 		for (CompressionAlgorithm algo : _algorithms) {
 			builder.append(algo.getSettingsString());
@@ -198,7 +198,7 @@ public class CompressTrackFunction extends MarkAndDeleteFunction
 	 */
 	private void initDialogFromConfig()
 	{
-		String params = Config.getConfigString(Config.KEY_COMPRESSION_SETTINGS);
+		String params = getConfig().getConfigString(Config.KEY_COMPRESSION_SETTINGS);
 		if (params == null || params.isEmpty()) {
 			return;
 		}
