@@ -26,34 +26,36 @@ public class AltitudeData extends ProfileData
 		setUnitSet(inUnitSet);
 		initArrays();
 		_hasData = false;
+		if (_track == null || _track.getNumPoints() < 1) {
+			return;
+		}
 		// multiplication factor for unit conversion
 		final double multFactor = _unitSet.getAltitudeUnit().getMultFactorFromStd();
-		if (_track != null)
+		try
 		{
-			try
+			for (int i=0; i<_track.getNumPoints(); i++)
 			{
-				for (int i=0; i<_track.getNumPoints(); i++)
+				DataPoint point = _track.getPoint(i);
+				if (point != null && point.hasAltitude())
 				{
-					DataPoint point = _track.getPoint(i);
-					if (point != null && point.hasAltitude())
-					{
-						// Point has an altitude - store value and maintain max and min values
-						double value = point.getAltitude().getMetricValue() * multFactor;
-						_pointValues[i] = value;
-						if (value < _minValue || !_hasData) {_minValue = value;}
-						if (value > _maxValue || !_hasData) {_maxValue = value;}
+					// Point has an altitude - store value and maintain max and min values
+					double value = point.getAltitude().getMetricValue() * multFactor;
+					_pointValues[i] = value;
+					if (value < _minValue || !_hasData) {_minValue = value;}
+					if (value > _maxValue || !_hasData) {_maxValue = value;}
 
-						// if all values are zero then that's no data
-						_hasData = _hasData || (point.getAltitude().getValue() != 0);
-						_pointHasData[i] = true;
-					}
-					else _pointHasData[i] = false;
+					// if all values are zero then that's no data
+					_hasData = _hasData || (point.getAltitude().getValue() != 0.0);
+					_pointHasData[i] = true;
+				}
+				else {
+					_pointHasData[i] = false;
 				}
 			}
-			catch (ArrayIndexOutOfBoundsException obe)
-			{} // must be due to the track size changing during calculation
-			   // assume that a redraw will be triggered
 		}
+		catch (ArrayIndexOutOfBoundsException obe)
+		{} // must be due to the track size changing during calculation
+		   // assume that a redraw will be triggered
 	}
 
 	/**
