@@ -3,14 +3,14 @@ package tim.prune.load;
 import javax.swing.JFrame;
 
 import tim.prune.function.Cancellable;
-import tim.prune.gui.GenericProgressDialog;
+import tim.prune.gui.ProgressDialog;
 
 /**
  * Class to show a progress dialog for loading media.
  * Used for regular photo / audio loads plus the async loading function.
  * Maybe this class isn't really needed...
  */
-public class MediaLoadProgressDialog extends GenericProgressDialog
+public class MediaLoadProgressDialog extends ProgressDialog
 {
 	/**
 	 * Constructor
@@ -19,6 +19,6 @@ public class MediaLoadProgressDialog extends GenericProgressDialog
 	 */
 	public MediaLoadProgressDialog(JFrame inParentFrame, Cancellable inFunction)
 	{
-		super("dialog.jpegload.progress.title", "dialog.jpegload.progress", inParentFrame, inFunction);
+		super(inParentFrame, "dialog.jpegload.progress.title", "dialog.jpegload.progress", inFunction);
 	}
 }
